# Creating Custom Prompts for AIPR

AIPR's custom prompt system allows you to tailor how pull request descriptions are generated by providing your own XML-based prompt template. This tutorial will guide you through creating and using custom prompts.

## Why Use Custom Prompts?

Custom prompts enable you to:
- Define specific formatting for your team's merge requests
- Add organization-specific guidelines or requirements
- Include custom sections or validation rules
- Provide examples that match your team's best practices

## Basic Structure

A custom prompt template is an XML file with the following required elements:
```xml
<?xml version="1.0" encoding="UTF-8"?>
<prompt>
    <changes-set></changes-set>
    <vulnerabilities-set></vulnerabilities-set>
</prompt>
```

The two required elements are:
- `<changes-set>`: Where git diff changes will be inserted
- `<vulnerabilities-set>`: Where vulnerability scan data will be inserted (if available)

## Optional Elements

You can enhance your prompt with these optional elements:

### System Context
```xml
<system>
    You are generating merge request descriptions following our team's guidelines.
    Focus on technical accuracy and clarity.
    Include impact analysis for each change.
</system>
```

### Instructions
```xml
<instructions>
    Follow these specific rules when generating the description:
    1. Use bullet points for all changes
    2. Group related changes under clear headings
    3. Always include line numbers for significant changes
    4. Highlight any breaking changes in bold
    5. List all modified configuration files separately
</instructions>
```

### Description Structure
```xml
<description>
    Please create a merge request description that includes:
    - Summary of changes
    - Technical implementation details
    - Testing performed
    - Migration steps (if any)
    - Security considerations
</description>
```

### Example Output
```xml
<example>
    ## Summary
    Added input validation to user registration API

    ## Implementation
    - Implemented zxcvbn for password strength validation
    - Added email format validation
    - Added rate limiting for registration attempts

    ## Testing
    - Unit tests: 100% coverage
    - Integration tests added
    - Load tested with 1000 concurrent requests

    ## Security Impact
    - Prevents weak passwords
    - Mitigates brute force attacks
</example>
```


## Using Custom Prompts

1. Save your prompt template with a `.xml` extension (e.g., `team-prompt.xml`)
2. Use the `-p/--prompt` option with the path to your template:
   ```bash
   aipr -p docs/yoda_prompt.xml
   ```

## Best Practices

1. **Be Specific**: Provide clear instructions about what should be included
2. **Use Examples**: Include examples that demonstrate your desired format
3. **Consider Context**: Include relevant organizational context in the system prompt
4. **Validate**: Test your prompt with different types of changes
5. **Iterate**: Refine your prompt based on feedback
